package de.lmu.mobilehci.locationaudio;

import java.io.File;
import java.io.IOException;

import android.app.Activity;
import android.content.Intent;
import android.media.MediaRecorder;
import android.os.Bundle;
import android.os.Environment;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;

public class SoundRecorderActivity extends Activity {

	private MediaRecorder recorder = null;
	private TextView statusView = null;

	private Button recordingStartButton = null;
	private Button recordingStopButton = null;
	
	private SoundInfo soundInfo = null;

	
	
	public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
    }

    
    
    protected void onResume() {
    	super.onResume();
    	soundInfo = new SoundInfo();
        soundInfo.poiId = getIntent().getIntExtra("poiId", 0);
    }
    
	
    
	protected void onPause() {
		super.onPause();
		stopRecordingdAudio();
	}

	
	
	public void onBackPressed() {
		stopRecordingdAudio();
		finish();
	}

	
	
	public void recordAudio() {
		if (soundInfo == null) return;

		recordingStartButton.setEnabled(false);
		recordingStopButton.setEnabled(true);

		TextView statusView = (TextView) findViewById(R.id.recording_status);
		statusView.setText("Aufnahme luft...");

		if (recorder != null) {
			recorder.stop();
			recorder.reset(); // can reuse the object by going back to
								// setAudioSource step
			recorder.release(); // now the object cannot be reused
			recorder = null;
		}

		recorder = new MediaRecorder();
		recorder.setAudioSource(MediaRecorder.AudioSource.MIC);
		recorder.setOutputFormat(MediaRecorder.OutputFormat.THREE_GPP);
		recorder.setAudioEncoder(MediaRecorder.AudioEncoder.AAC);

		boolean success = prepareSoundSquareDirectory();
		Log.d("SoundSquare", "prepareSoundSquareDirectory returned " + success);

		if (success) {
			long time = System.currentTimeMillis();
			soundInfo.path = soundSquareDirectoryName() + "/sound_" + time + ".mp3";
			recorder.setOutputFile(soundInfo.path);

			try {
				recorder.prepare();
				recorder.start(); // recording is now started
			} catch (IOException ex) {
				Log.d("SoundSquare", "Exception recordAudio: " + ex.toString());
				success = false;
			}
		}

		if (!success) {
			recorder.stop();
			recorder.reset();
			recorder.release();
			recorder = null;
			soundInfo.path = null;
			recordingStartButton.setEnabled(true);
			recordingStopButton.setEnabled(false);
			statusView.setText("Fehler beim Starten der Aufnahme!");
		}
	}
	
	
	
	public void stopRecordingdAudio() {

		recordingStartButton.setEnabled(true);
		recordingStopButton.setEnabled(false);

		if (recorder != null) {
			recorder.stop();
			recorder.reset(); 	// can reuse the object by going back to setAudioSource step
			recorder.release(); // now the object cannot be reused
			recorder = null;

			if (soundInfo != null) {
				EditText et = (EditText) findViewById(R.id.recording_description);
				soundInfo.description = et.getText().toString();

				int resultCode = (soundInfo.path == null) ? Activity.RESULT_CANCELED : Activity.RESULT_OK;

				Log.d("SoundSquare", "stopRecordingdAudio soundInfo = " + soundInfo);

				Intent resultData = new Intent();
				resultData.putExtra("soundInfo", soundInfo);
				setResult(resultCode, resultData);
			}

			statusView.setText("Aufnahme beendet.");
			finish();
		}
	}
	
	
	
	public String soundSquareDirectoryName() {
		String directoryName = Environment.getExternalStorageDirectory().toString() + "/SoundSquare";
		Log.d("SoundSquare", "soundSquareDirectoryName = " + directoryName);
		return directoryName;
	}

	
	
	public boolean prepareSoundSquareDirectory() {
		Log.d("SoundSquare", "prepareSoundSquareDirectory");
		
		String directoryName = soundSquareDirectoryName();
		File directory = new File(directoryName);
		
		if (!directory.isDirectory()) {
			if (!directory.mkdirs()) {
				return false;
			}
		}
		
		return true;
	}
	
	
	
}
